<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="az">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Tətbiq proksisi</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proksi növü</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Ünvanı</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>İxtiyari</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Tənzimləndikdən sonra Başladıcıda, tətbiqin kontekst menyusundakı &quot;Proksi istifadə edin&quot; işarələyin</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Ləğv edin</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Saxla</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Səhv İP ünvanı</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Səhv port</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Bağlantını ləğv et</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Ləğv edin</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Saxla</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Qoşulur</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Bağlantını ləğv et</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Bu tənzimləmənisilmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Naqilli bağlantı %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Qoşulma nöqtəsi</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Simsiz bağlantı %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE bağlantı %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Yeni VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN Növü</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>İxrac edin</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Şəbəkə</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Tətbiq proksisi</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Fərdi qoşulma nöqtəsi</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Şəbəkə məlumatları</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Sistem proksisi</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Naqilli şəbəkə</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Simsiz şəbəkə</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Təyyarə rejimi</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Naqilli şəbəkə uzlaşdırıcısı</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Şəbəkə bağlantısı əlavə et</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Simsiz şəbəkə uzlaşdırıcısı</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Gizli şəbəkəyə qoşulmaq</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE bağlantısı yaratmaq</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN statusu</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN yaratmaq</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN idxal etmək</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proksi növü</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Tənzimləmə URL&apos;u</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Ünvanı</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Qoşulma nöqtəsi</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Qoşulma nöqtəsi yaratmaq</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>İnterfeys</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Aralıq</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Şəbəkə keçidi</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Birinci DNS</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Şəbəkə maskası</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Sürət</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Təyyarə rejimi</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Təyyarə rejiminin işə salınması simsiz şəbəkəni, fərdi qoşulma nötəsini və Bluetooth-u söndürür</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Səhv DNS ünvanı</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Qoşulu deyil</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Cihazın MAC ünvanı</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Klonlaşdırılmış MAC ünvanı</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Fərdi MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Ümumi</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Ümumi</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Bu ad artıq var</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Avtomatik bağlantı</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Qoşulma nöqtəsi</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Ayarlar əlavə etmək</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Qoşulma nöqtəsi yaratmaq</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP Ünvanı</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Şəbəkə keçidi</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>İP ünvanının təkrarı</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Səhv İP ünvanı</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Səhv şəbəkə maskası</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Yalnız bir şəbəkə keçidinə icazə verilir</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Səhv şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Şəbəkə maskası</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>İP ünvanının təkrarı</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Səhv İP ünvanı</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Yalnız bir şəbəkə keçidinə icazə verilir</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Səhv şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Avtomatik</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Əllə</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>İmtina et</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Ünvanı</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Yalnız uyğun gələn mənbələrdə tətbiq edilir</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Üsul</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Şəbəkə maskası</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefiks</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Səhv İP ünvanı</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Səhv şəbəkə maskası</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Səhv şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Şəbəkə</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>İP ziddiyyəti</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Üsul</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Avtomatik</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Əl ilə</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>İmtina edin</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Şəbəkə məlumatları</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Sistem proksisi</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Tətbiq proksisi</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Təyyarə rejimi</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Şəbəkə məlumatları</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Şəbəkə</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>İP ziddiyyəti</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Aktiv deyil</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Əllə</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Avtomatik</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Şəbəkə Meneceri ilə ayarlamaq</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Fərdi qoşulma nöqtəsi</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servis</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP doğrulamasındn imtina etmək</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP doğrulamasından imtina etmək</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP doğrulamasından imtina etmək</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP doğrulamasından imtina etmək</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 doğrulamasıdan imtina etmək</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD verilənlərini sıxmadan</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Deflate verilənləri sıxılmadan</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP başlıqları sıxılmadan</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Protokol sahəsini sıxmadan</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ünvan/İdarəetmə sıxılmadan</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP exo-paketlərini göndərmək</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE istifadə et</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE vəziyyəti</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE bağlantısı yaratmaq</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Sistem proksisi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Ləğv edin</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Saxla</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proksi növü</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Əllə</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Avtomatik</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>İxtiyari</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP proksi</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS proksi</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP proksi</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS proksi</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Yuxarıdakı hostlar və domenlər üçün proksi tənzimləmələrini nəzərə almamaq</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Tənzimləmə URL&apos;u</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Təhlükəsizlik</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunellənmiş TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Qorunan EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Şifrəni bu istifadəçi üçün saxlamaq</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Şifrəni bütün istifadəçilər üçün saxlamaq</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Həmişə söruşsun</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Aktiv deyil</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonim</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Doğrulanmış</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Hər ikisi</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Avtomatik</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versiya0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versiya 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP doğrulaması</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Kimlik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Şifrə seçimləri</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Məxfi açar</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA sertifikatı</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>İstifadəçi sertifikatı</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonim ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Təminat</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC faylı</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Daxili kimlik doğrulaması</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP versiyası</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Məxfi şifrə</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Səhv şifrə</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Təhlükəsizlik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Açar</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Təhlükəsizlik tələb olunur</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Səhv şifrə</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Paylaşılan açar</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Sistemi açmaq</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Təhlükəsizlik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Kimlik doğrulaması</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Açar</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Təkmilləşmiş VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Fərdi Şəbəkə keçidi portu</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Şəbəkə keçidi portu</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Yenidən uyğunlaşdırma aralığını ayarlamaq</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Yenidən uyğunlaşdırma aralığı</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO verilənlərinin sıxılmasından istifadə etmək</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP bağlantısını istifadə etmək</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP cihazını istifadə etmək</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>MTU tunelini ayarlamaq</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP fraqmentinin ölçüsünü ayarlamaq</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP fraqmentinin ölçüsü</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>TCP MSS tunelini məhdudlaşdırmaq</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Təsadüfi uzaq hostlar</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Təkmilləşmiş VPN</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (varsayılan)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Təhlükəsizlik (varsayılan)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Zəif</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T mövcud olduqda (varsayılan)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T həmişə</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Aktiv deyil</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH 1 qrupu</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH 2  qrupu (varsayılan)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH 5 qrupu</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (varsayılan)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH 2 qrupu</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domen</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Satıcı</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versiya</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Şifrələmə</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT keçid rejimi</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>İKE DH qrupu</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Ötürmə gizliliyi</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Yerli port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Qeyri-işlək iştirakçıların ləğv edilməsi</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>İPsec aktiv etmək</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Qrup adı</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Qrup ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Əvvəlcədən paylaşılan açar</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 alqoritmləri</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2 alqoritmləri</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Səhv şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA sertifikatı</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proksi</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Cisco Secure Desktop troyanına icazə vermək</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Skripti</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>İstifadəçi sertifikatı</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Məxfi açar</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Açar şifrəsi üçün FSİD istifadə edin</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Səhv şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Sertifikatlar (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Şifrəli sertifikatlar (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statik açar</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Saxlanıldı</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Soruş</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tələb olunmur</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Kimlik doğrulaması növü</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA sertifikatı</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>İstifadəçi sertifikatı</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Məxfi açar</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Şifrə seçimləri</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Məxfi şifrə</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Əsas istiqaməti ayarlayın</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Əsas istiqamət</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Uzaq İP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Yerlo İP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Bütün mövcud olanlar (varsayılan)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (az etibarlı)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (ən etibarlı)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP doğrulamasındn imtina etmək</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP doğrulamasından imtina etmək</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP doğrulamasından imtina etmək</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP doğrulamasından imtina etmək</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 doğrulamasıdan imtina etmək</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD verilənlərini sıxmadan</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Deflate verilənləri sıxılmadan</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP başlıqları sıxılmadan</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Protokol sahəsini sıxmadan</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Ünvan/İdarəetmə sıxılmadan</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP exo-paketlərini göndərmək</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE istifadə et</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Təhlükəsizlik</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE vəziyyəti</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN statusu</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN yaratmaq</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN idxal etmək</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>İdxal alınmadı</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Fayl xətası</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN proksi</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tələb olunmur</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proksi növü</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server İP-si</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Alınmadıqda daima təkrarlamaq</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA faylı</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Sertifikat xəbərdarlığına məhəl qoymamaq</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLS host adı uzantılarını istifadə edin</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN təhlükəsizliyi</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Şifr</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation> HMAC doğrulaması</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Səhv şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Saxlanıldı</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Soruş</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tələb olunmur</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Şifrə seçimləri</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT domen</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN proksi</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server İP-si</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Səhv şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Məxfi açar</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Smart-kart</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Əvvəlcədən paylaşılan açar</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA sertifikatı</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Kimlik doğrulaması növü</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>İstifadəçi sertifikatı</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Daxili İP ünvanı tələb etmək</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP encapsulasionu tətbiq etmək</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>İP sıxılmasını istifadə etmək</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>İstifadəçi şifrləri təkliflərini aktiv etmək</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS doğrulaması</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Müştəri</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Mövzu uyğunluğu </translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Uzaq sertifikat növü</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Açar faylı</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Əsas istiqaməti ayarlayın</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Əsas istiqamət</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Səhv şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Saxlanıldı</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Soruş</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Tələb olunmur</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Şəbəkə keçidi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Şifrə seçimləri</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Qrup adı</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Qrup şifrəsi</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Hibrid doğrulamadan istifadə etmək</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA faylı</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Öncə şəbəkə kabelini qoşun</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Naqilli şəbəkə uzlaşdırıcısı</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Şəbəkə bağlantısı əlavə et</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Ayarları seçin</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Simsiz şəbəkə uzlaşdırıcısı</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Qoşulma nöqtəsini bağlamaq</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Simsiz şəbəkəyə bağlanmaq istəsəniz qoşulma nöqtəsini söndürün</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Gizli şəbəkəyə qoşulmaq</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Qoşulu deyil</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Tələb olunur</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Cihazın MAC ünvanı</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Fərdi MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>